@@ -1,12 +1,16 @@
 ;;; disproject.el --- Dispatch project commands with Transient  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 1985-1987, 1992-2026 Free Software Foundation, Inc.
+;; Copyright (C) 2024-2025 Alvin Hsu
+;; Copyright (C) 2008-2023 The Magit Project Contributors
+;; Copyright (C) 1985-1987, 1992-2025 Free Software Foundation, Inc.
 
 ;; Author: Alvin Hsu <aurtzy@gmail.com>
 ;; Maintainer: Alvin Hsu <aurtzy@gmail.com>
 ;; URL: https://github.com/aurtzy/disproject
 ;; Keywords: convenience, files, vc
-;; Version: 2.2.0
+
+;; Package-Version: 20251007.310
+;; Package-Revision: c2b14a5e1b1e
 ;; Package-Requires: ((emacs "29.4") (transient "0.9.2"))
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -33,7 +37,9 @@
 ;;; Code:
 
 
-;;;; Initial code.
+;;;
+;;; Initial code.
+;;;
 
 (require 'cus-edit)
 (require 'eieio)
@@ -45,10 +51,12 @@
 (require 'transient)
 
 
-;;;; Options.
+;;;
+;;; Options.
+;;;
 
 
-;;;;; Customization groups.
+;;;; Customization groups.
 
 (defgroup disproject nil
   "Transient interface for managing and interacting with projects."
@@ -66,7 +74,7 @@ order to apply as expected."
   :group 'disproject)
 
 
-;;;;; Variables.
+;;;; Variables.
 
 (defcustom disproject-custom-allowed-suffixes '()
   "Allowed values for `disproject-custom-suffixes'."
@@ -267,10 +275,14 @@ This is used in the command `disproject-vc-status'."
   :group 'disproject-swappable-commands)
 
 
-;;;; Faces.
+;;;
+;;; Faces.
+;;;
 
 
-;;;; Conditional feature predicates/forms.
+;;;
+;;; Conditional feature predicates/forms.
+;;;
 ;; NOTE: The `disproject-prefix-*' predicates are specifically meant for usage
 ;; during transient setup of `disproject-prefix' prefixes (or subclasses of).
 ;; Calling these in any other situation may lead to unexpected/undesired
@@ -298,15 +310,15 @@ This is used in the command `disproject-vc-status'."
 
 (defun disproject-prefix--in-default-project? ()
   "Return non-nil if the selected project is also the default project."
-  (and-let* ((scope (transient-scope)))
-    (disproject-scope-project-is-default? scope)))
+  (if-let* ((scope (transient-scope)))
+      (disproject-scope-project-is-default? scope)))
 
 (defun disproject-prefix--magit-apt? ()
   "Return non-nil if magit commands are apt to show."
-  (and-let* ((_ (featurep 'magit))
-             (scope (transient-scope))
-             (project (disproject-scope-selected-project scope)))
-    (eq 'Git (disproject-project-backend project))))
+  (and (featurep 'magit)
+       (if-let* ((scope (transient-scope))
+                 (project (disproject-scope-selected-project scope)))
+           (eq 'Git (disproject-project-backend project)))))
 
 (defun disproject-prefix--magit-todos-apt? ()
   "Return non-nil if the `magit-todos' is available."
@@ -327,10 +339,12 @@ project."
     t))
 
 
-;;;; Transient groups.
+;;;
+;;; Transient groups.
+;;;
 
 
-;;;;; Definitions.
+;;;; Definitions.
 
 (transient-define-group disproject-global-header-group
   disproject--selected-project-header-group
@@ -346,9 +360,9 @@ project."
   [:description disproject--selected-project-description ""])
 
 
-;;;;; Dynamic group definitions.
+;;;; Dynamic group definitions.
 
-;;;;;; Auxiliary.
+;;;;; Auxiliary.
 
 (defun disproject--group-insert-defaults (group-spec &optional reached-keywords?
                                                      &rest keyword-values)
@@ -438,7 +452,7 @@ specification that uses some transient suffix class with this
 keyword."
   (and (listp spec) (memq :command-type spec)))
 
-;;;;;; Setup functions.
+;;;;; Setup functions.
 
 (defvar disproject-custom--showed-custom-spec-deprecation? nil
   "Whether deprecation message for the custom specification syntax has been shown.")
@@ -496,10 +510,12 @@ Defining custom suffixes with Disproject's custom syntax is deprecated;\
     (transient-parse-suffixes 'disproject-find-special-file-dispatch suffixes)))
 
 
-;;;; Classes.
+;;;
+;;; Classes.
+;;;
 
 
-;;;;; `disproject-project' class.
+;;;; `disproject-project' class.
 
 (defclass disproject-project ()
   ;; root must be a path to a valid project.  An `initialize-instance' method
@@ -557,8 +573,8 @@ project as a last step of initialization."
   "Return a `disproject-project' instance for DIRECTORY, or maybe nil.
 
 DIRECTORY is passed to `project-current' to detect a project."
-  (and-let* ((project (project-current nil directory)))
-    (disproject-project :root (project-root project))))
+  (if-let* ((project (project-current nil directory)))
+      (disproject-project :root (project-root project))))
 
 (cl-defmethod disproject-project-backend ((obj disproject-project))
   "Return the OBJ project backend.
@@ -599,7 +615,7 @@ This internally uses `project-try-vc' to determine the backend."
             (default-value 'disproject-custom-suffixes)))))
 
 
-;;;;; `disproject-scope' class.
+;;;; `disproject-scope' class.
 
 (defclass disproject-scope ()
   ((selected-project :initarg :selected-project
@@ -725,7 +741,7 @@ different scope objects to be created (which is not usually desired)."
       (transient-scope 'disproject-dispatch 'disproject-prefix)))
 
 
-;;;;; `disproject-process-suffix' class.
+;;;; `disproject-process-suffix' class.
 
 (defclass disproject-process-suffix (transient-suffix)
   ((buffer-id :initarg :buffer-id
@@ -798,31 +814,31 @@ If the `display-status?' slot is non-nil and
 formatted with an indicator that describes the associated process
 buffer's current status."
   ;; Preserve the transient "bug" warning if there is no description.
-  (and-let* ((description (cl-call-next-method)))
-    (if-let* (((and (oref obj display-status?)
-                    (null (oref obj allow-multiple-buffers?))))
-              (project (disproject-scope-selected-project (disproject--scope)))
-              (project-name (project-name
-                             (disproject-project-instance project)))
-              (buf-name (disproject-process-suffix-buffer-name obj project-name))
-              (buffer (get-buffer buf-name)))
-        (progn
-          ;; Refresh transient if process status changes.
-          (disproject-add-sentinel-refresh-transient buf-name)
-          (concat (cond
-                   ((null buffer)
-                    "")
-                   ((get-buffer-process buffer)
-                    (concat (propertize "[a]" 'face 'transient-enabled-suffix)
-                            " "))
-                   (t
-                    (concat (propertize "[i]" 'face 'transient-inactive-value)
-                            " ")))
-                  description))
-      description)))
+  (if-let* ((description (cl-call-next-method)))
+      (if-let* (((and (oref obj display-status?)
+                      (null (oref obj allow-multiple-buffers?))))
+                (project (disproject-scope-selected-project (disproject--scope)))
+                (project-name (project-name
+                               (disproject-project-instance project)))
+                (buf-name (disproject-process-suffix-buffer-name obj project-name))
+                (buffer (get-buffer buf-name)))
+          (progn
+            ;; Refresh transient if process status changes.
+            (disproject-add-sentinel-refresh-transient buf-name)
+            (concat (cond
+                     ((null buffer)
+                      "")
+                     ((get-buffer-process buffer)
+                      (concat (propertize "[a]" 'face 'transient-enabled-suffix)
+                              " "))
+                     (t
+                      (concat (propertize "[i]" 'face 'transient-inactive-value)
+                              " ")))
+                    description))
+        description)))
 
 
-;;;;; `disproject-shell-command-suffix' class.
+;;;; `disproject-shell-command-suffix' class.
 
 (defclass disproject-shell-command-suffix (disproject-process-suffix)
   ((cmd :initarg :cmd
@@ -868,7 +884,7 @@ When unable to convert to a string, throw an error."
      (t (user-error "Not a string or command: %s" cmd)))))
 
 
-;;;;; `disproject-compilation-suffix' class.
+;;;; `disproject-compilation-suffix' class.
 
 (defclass disproject-compilation-suffix (disproject-shell-command-suffix)
   ((comint? :initarg :comint?
@@ -882,7 +898,7 @@ order to conditionally enable the mode.")
   "Class for suffixes that utilize the `compile' command for shell commands.")
 
 
-;;;;; `disproject-display-buffer-action-suffix' class.
+;;;; `disproject-display-buffer-action-suffix' class.
 
 (defclass disproject-display-buffer-action-suffix (transient-suffix)
   ((display-buffer-action :initarg :display-buffer-action
@@ -903,7 +919,7 @@ through a shared object in the transient scope."))
   "Class for suffixes that manage `display-buffer' action settings.")
 
 
-;;;;; `disproject-find-special-file-suffix' class.
+;;;; `disproject-find-special-file-suffix' class.
 
 (defclass disproject-find-special-file-suffix (transient-suffix)
   ((file :initarg :file
@@ -972,7 +988,7 @@ same as `transient-suffix' for formatting descriptions."
       (propertize "(BUG: no description; no project in scope)" 'face 'error))))
 
 
-;;;;; `disproject-prefix' class.
+;;;; `disproject-prefix' class.
 
 (defclass disproject-prefix (transient-prefix) ()
   "General Disproject prefix class.
@@ -996,7 +1012,7 @@ if it hasn't already been initialized."
       (oset obj scope (disproject-scope)))))
 
 
-;;;;; `disproject--selected-project-prefix' class.
+;;;; `disproject--selected-project-prefix' class.
 
 (defclass disproject--selected-project-prefix (disproject-prefix) ()
   "Class for Disproject prefixes that require a project to be selected.")
@@ -1007,7 +1023,7 @@ if it hasn't already been initialized."
   (disproject-scope-selected-project-ensure (oref obj scope)))
 
 
-;;;;; `disproject--custom-suffixes-prefix' class.
+;;;; `disproject--custom-suffixes-prefix' class.
 
 (defclass disproject--custom-suffixes-prefix
   (disproject--selected-project-prefix) ()
@@ -1020,14 +1036,16 @@ if it hasn't already been initialized."
    (disproject-scope-selected-project-ensure (oref obj scope))))
 
 
-;;;; Commands.
+;;;
+;;; Commands.
+;;;
 
 
-;;;;; Interactive functions.
+;;;; Interactive functions.
 
-;;;;;; Auxiliary.
+;;;;; Auxiliary.
 
-;;;;;; Definitions.
+;;;;; Definitions.
 
 (defun disproject-default-find-line (regexp)
   "Find matching line in buffers associated with the current project.
@@ -1044,11 +1062,11 @@ This uses `multi-occur' under the hood."
     (error "No project in current directory: %s" default-directory)))
 
 
-;;;;; Transient infixes.
+;;;; Transient infixes.
 
-;;;;;; Auxiliary.
+;;;;; Auxiliary.
 
-;;;;;; Definitions.
+;;;;; Definitions.
 
 (transient-define-infix disproject-infix-customize-switch ()
   :description "Use Customize interface"
@@ -1058,9 +1076,9 @@ This uses `multi-occur' under the hood."
   :if #'disproject-prefix--customize-dirlocals-apt?)
 
 
-;;;;; Transient suffixes.
+;;;; Transient suffixes.
 
-;;;;;; Auxiliary.
+;;;;; Auxiliary.
 
 (defun disproject-add-sentinel-refresh-transient (buffer-name)
   "Add function to a buffer's process sentinel to refresh transient, if active.
@@ -1287,8 +1305,8 @@ value is passed, this function will not do anything."
                                 :test #'equal)))
     (cl-remove-duplicates
      (seq-mapcat (lambda (directory)
-                   (and-let* ((project (project-current nil directory)))
-                     (list project)))
+                   (if-let* ((project (project-current nil directory)))
+                       (list project)))
                  directories)
      :test (lambda (p1 p2) (equal (project-root p1) (project-root p2))))))
 
@@ -1306,7 +1324,7 @@ project."
   (setf (disproject-scope-selected-project (disproject--scope))
         (disproject-project :root search-directory)))
 
-;;;;;; Suffix environment.
+;;;;; Suffix environment.
 
 (defvar disproject--environment-buffer-name " disproject-environment"
   "Name of buffer which commands will be run from.")
@@ -1450,7 +1468,7 @@ This is an alias for `disproject-with-env+root'."
   (declare (indent 0) (debug t))
   `(disproject-with-env+root ,@body))
 
-;;;;;; Definitions.
+;;;;; Definitions.
 
 (transient-define-suffix disproject-compile ()
   "Run a shell command with `compile' in project root.
@@ -1583,19 +1601,19 @@ documentation on transient suffix slots."
   :class disproject-display-buffer-action-suffix
   :transient #'transient--do-return
   (interactive)
-  (and-let* ((scope (disproject--scope))
-             (suffix (transient-suffix-object)))
-    (setf (disproject-scope-display-buffer-action scope)
-          (let ((action (oref suffix display-buffer-action)))
-            (pcase-exhaustive action
-              ('nil
-               nil)
-              (`(,_functions . ,(map ('description (pred (not null)))))
-               action)
-              (`(,functions . ,alist)
-               `(,functions . ((description
-                                . ,(transient-format-description suffix))
-                               ,@alist))))))))
+  (if-let* ((scope (disproject--scope))
+            (suffix (transient-suffix-object)))
+      (setf (disproject-scope-display-buffer-action scope)
+            (let ((action (oref suffix display-buffer-action)))
+              (pcase-exhaustive action
+                ('nil
+                 nil)
+                (`(,_functions . ,(map ('description (pred (not null)))))
+                 action)
+                (`(,functions . ,alist)
+                 `(,functions . ((description
+                                  . ,(transient-format-description suffix))
+                                 ,@alist))))))))
 
 (transient-define-suffix disproject-execute-extended-command ()
   "Execute an extended command in project root."
@@ -1942,9 +1960,9 @@ be called interactively."
          (alist-get nil disproject-vc-status-commands))))))
 
 
-;;;;; Transient prefixes.
+;;;; Transient prefixes.
 
-;;;;;; Auxiliary.
+;;;;; Auxiliary.
 
 (defun disproject--assert-type (variable value)
   "Assert that VALUE matches the type for custom VARIABLE.
@@ -2066,7 +2084,7 @@ n -- to ignore them and use the default custom suffixes.
               (propertize root 'face 'transient-value)
             (propertize "None detected" 'face 'transient-inapt-suffix))))
 
-;;;;;; Definitions.
+;;;;; Definitions.
 
 ;;;###autoload (autoload 'disproject-dispatch "disproject" nil t)
 (transient-define-prefix disproject-dispatch ()
@@ -2211,8 +2229,7 @@ defining commands that can modify the override state."
     :display-buffer-action (display-buffer-use-some-window
                             (inhibit-same-window . t)))
    ("s" "same window" disproject-display-buffer-action-set
-    :display-buffer-action (display-buffer-same-window
-                            (inhibit-same-window . nil)))]
+    :display-buffer-action (display-buffer-same-window))]
   [("," "Clear override" disproject-display-buffer-action-set)])
 
 (transient-augment-suffix disproject-display-buffer-action-dispatch
@@ -2234,7 +2251,9 @@ defining commands that can modify the override state."
             ")")))
 
 
-;;;; Short-documentation groups.
+;;;
+;;; Short-documentation groups.
+;;;
 
 (define-short-documentation-group disproject-customizable-suffixes
   "Customizable Disproject suffixes
